==> epiphany-2.20.3.tar.bz2: epiphany-2.20.3/src/ephy-link-action.h <==
/*
 *  Copyright © 2004 Christian Persch
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 *  $Id: ephy-link-action.h 6952 2007-03-11 19:42:02Z chpe $
 */

#ifndef EPHY_LINK_ACTION_H
#define EPHY_LINK_ACTION_H

#include <gtk/gtkaction.h>
#include <gtk/gtkactiongroup.h>

G_BEGIN_DECLS

#define EPHY_TYPE_LINK_ACTION			(ephy_link_action_get_type ())
#define EPHY_LINK_ACTION(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_LINK_ACTION, EphyLinkAction))
#define EPHY_LINK_ACTION_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_LINK_ACTION, EphyLinkActionClass))
#define EPHY_IS_LINK_ACTION(o)			(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_LINK_ACTION))
#define EPHY_IS_LINK_ACTION_CLASS(k)		(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_LINK_ACTION))
#define EPHY_LINK_ACTION_GET_CLASS(o)		(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_LINK_ACTION, EphyLinkActionClass))

#define EPHY_TYPE_LINK_ACTION_GROUP		(ephy_link_action_group_get_type ())
#define EPHY_LINK_ACTION_GROUP(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_LINK_ACTION_GROUP, EphyLinkActionGroup))
#define EPHY_LINK_ACTION_GROUP_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_LINK_ACTION_GROUP, EphyLinkActionGroupClass))
#define EPHY_IS_LINK_ACTION_GROUP(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_LINK_ACTION_GROUP))
#define EPHY_IS_LINK_ACTION_GROUP_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_LINK_ACTION_GROUP))
#define EPHY_LINK_ACTION_GROUP_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_LINK_ACTION_GROUP, EphyLinkActionGroupClass))

typedef struct _EphyLinkAction			EphyLinkAction;
typedef struct _EphyLinkActionClass		EphyLinkActionClass;

typedef struct _EphyLinkActionGroup		EphyLinkActionGroup;
typedef struct _EphyLinkActionGroupClass	EphyLinkActionGroupClass;

struct _EphyLinkAction
{
	GtkAction parent_instance;
};

struct _EphyLinkActionClass
{
	GtkActionClass parent_class;
};

struct _EphyLinkActionGroup
{
	GtkActionGroup parent_instance;
};

struct _EphyLinkActionGroupClass
{
	GtkActionGroupClass parent_class;
};

GType ephy_link_action_get_type	(void);

GType ephy_link_action_group_get_type (void);

EphyLinkActionGroup * ephy_link_action_group_new (const char *name);

G_END_DECLS

#endif

==> epiphany-2.26.3.tar.bz2: epiphany-2.26.3/src/ephy-link-action.h <==
/*
 *  Copyright © 2004 Christian Persch
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 *  $Id$
 */

#ifndef EPHY_LINK_ACTION_H
#define EPHY_LINK_ACTION_H

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define EPHY_TYPE_LINK_ACTION			(ephy_link_action_get_type ())
#define EPHY_LINK_ACTION(o)			(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_LINK_ACTION, EphyLinkAction))
#define EPHY_LINK_ACTION_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_LINK_ACTION, EphyLinkActionClass))
#define EPHY_IS_LINK_ACTION(o)			(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_LINK_ACTION))
#define EPHY_IS_LINK_ACTION_CLASS(k)		(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_LINK_ACTION))
#define EPHY_LINK_ACTION_GET_CLASS(o)		(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_LINK_ACTION, EphyLinkActionClass))

#define EPHY_TYPE_LINK_ACTION_GROUP		(ephy_link_action_group_get_type ())
#define EPHY_LINK_ACTION_GROUP(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_LINK_ACTION_GROUP, EphyLinkActionGroup))
#define EPHY_LINK_ACTION_GROUP_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_LINK_ACTION_GROUP, EphyLinkActionGroupClass))
#define EPHY_IS_LINK_ACTION_GROUP(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_LINK_ACTION_GROUP))
#define EPHY_IS_LINK_ACTION_GROUP_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_LINK_ACTION_GROUP))
#define EPHY_LINK_ACTION_GROUP_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_LINK_ACTION_GROUP, EphyLinkActionGroupClass))

typedef struct _EphyLinkAction			EphyLinkAction;
typedef struct _EphyLinkActionClass		EphyLinkActionClass;

typedef struct _EphyLinkActionGroup		EphyLinkActionGroup;
typedef struct _EphyLinkActionGroupClass	EphyLinkActionGroupClass;

struct _EphyLinkAction
{
	GtkAction parent_instance;
};

struct _EphyLinkActionClass
{
	GtkActionClass parent_class;
};

struct _EphyLinkActionGroup
{
	GtkActionGroup parent_instance;
};

struct _EphyLinkActionGroupClass
{
	GtkActionGroupClass parent_class;
};

GType ephy_link_action_get_type	(void);

GType ephy_link_action_group_get_type (void);

EphyLinkActionGroup * ephy_link_action_group_new (const char *name);

G_END_DECLS

#endif
